@@ -18,24 +18,21 @@
 
 import os
 import platform
-import six
 import socket
 import tempfile
 import testtools
+from unittest import mock
 
 import eventlet
 import eventlet.wsgi
-import mock
 import requests
 import webob
 
 from oslo_config import cfg
-from oslo_service import _options
 from oslo_service import sslutils
 from oslo_service.tests import base
 from oslo_service import wsgi
 from oslo_utils import netutils
-from oslotest import moxstubout
 
 
 SSL_CERT_DIR = os.path.normpath(os.path.join(
@@ -48,8 +45,7 @@ class WsgiTestCase(base.ServiceBaseTestCase):
     """Base class for WSGI tests."""
 
     def setUp(self):
-        super(WsgiTestCase, self).setUp()
-        self.conf_fixture.register_opts(_options.wsgi_opts)
+        super().setUp()
         self.conf(args=[], default_config_files=[])
 
 
@@ -57,10 +53,11 @@ class TestLoaderNothingExists(WsgiTestCase):
     """Loader tests where os.path.exists always returns False."""
 
     def setUp(self):
-        super(TestLoaderNothingExists, self).setUp()
-        mox_fixture = self.useFixture(moxstubout.MoxStubout())
-        self.stubs = mox_fixture.stubs
-        self.stubs.Set(os.path, 'exists', lambda _: False)
+        super().setUp()
+        mock_patcher = mock.patch.object(os.path, 'exists',
+                                         lambda _: False)
+        mock_patcher.start()
+        self.addCleanup(mock_patcher.stop)
 
     def test_relpath_config_not_found(self):
         self.config(api_paste_config='api-paste.ini')
@@ -89,7 +86,7 @@ document_root = /tmp
     """
 
     def setUp(self):
-        super(TestLoaderNormalFilesystem, self).setUp()
+        super().setUp()
         self.paste_config = tempfile.NamedTemporaryFile(mode="w+t")
         self.paste_config.write(self._paste_config.lstrip())
         self.paste_config.seek(0)
@@ -114,14 +111,14 @@ document_root = /tmp
 
     def tearDown(self):
         self.paste_config.close()
-        super(TestLoaderNormalFilesystem, self).tearDown()
+        super().tearDown()
 
 
 class TestWSGIServer(WsgiTestCase):
     """WSGI server tests."""
 
     def setUp(self):
-        super(TestWSGIServer, self).setUp()
+        super().setUp()
 
     def test_no_app(self):
         server = wsgi.Server(self.conf, "test_app", None)
@@ -130,8 +127,8 @@ class TestWSGIServer(WsgiTestCase):
     def test_custom_max_header_line(self):
         self.config(max_header_line=4096)  # Default value is 16384
         wsgi.Server(self.conf, "test_custom_max_header_line", None)
-        self.assertEqual(self.conf.max_header_line,
-                         eventlet.wsgi.MAX_HEADER_LINE)
+        self.assertEqual(eventlet.wsgi.MAX_HEADER_LINE,
+                         self.conf.max_header_line)
 
     def test_start_random_port(self):
         server = wsgi.Server(self.conf, "test_random_port", None,
@@ -212,14 +209,14 @@ class TestWSGIServer(WsgiTestCase):
         uri = "http://127.0.0.1:%d/%s" % (server.port, 10000 * 'x')
         resp = requests.get(uri, proxies={"http": ""})
         eventlet.sleep(0)
-        self.assertNotEqual(resp.status_code,
-                            requests.codes.REQUEST_URI_TOO_LARGE)
+        self.assertNotEqual(requests.codes.REQUEST_URI_TOO_LARGE,
+                            resp.status_code)
 
         uri = "http://127.0.0.1:%d/%s" % (server.port, 20000 * 'x')
         resp = requests.get(uri, proxies={"http": ""})
         eventlet.sleep(0)
-        self.assertEqual(resp.status_code,
-                         requests.codes.REQUEST_URI_TOO_LARGE)
+        self.assertEqual(requests.codes.REQUEST_URI_TOO_LARGE,
+                         resp.status_code)
         server.stop()
         server.wait()
 
@@ -230,12 +227,12 @@ class TestWSGIServer(WsgiTestCase):
 
         # Stopping the server, which in turn sets pool size to 0
         server.stop()
-        self.assertEqual(server._pool.size, 0)
+        self.assertEqual(0, server._pool.size)
 
         # Resetting pool size to default
         server.reset()
         server.start()
-        self.assertEqual(server._pool.size, CONF.wsgi_default_pool_size)
+        self.assertEqual(CONF.wsgi_default_pool_size, server._pool.size)
 
     def test_client_socket_timeout(self):
         self.config(client_socket_timeout=5)
@@ -268,41 +265,59 @@ class TestWSGIServer(WsgiTestCase):
             server.stop()
 
 
+def requesting(host, port, ca_certs=None, method="POST",
+               content_type="application/x-www-form-urlencoded",
+               address_familly=socket.AF_INET):
+    frame = bytes("{verb} / HTTP/1.1\r\n\r\n".format(verb=method), "utf-8")
+    with socket.socket(address_familly, socket.SOCK_STREAM) as sock:
+        if ca_certs:
+            with eventlet.wrap_ssl(sock, ca_certs=ca_certs) as wrappedSocket:
+                wrappedSocket.connect((host, port))
+                wrappedSocket.send(frame)
+                data = wrappedSocket.recv(1024).decode()
+                return data
+        else:
+            sock.connect((host, port))
+            sock.send(frame)
+            data = sock.recv(1024).decode()
+            return data
+
+
 class TestWSGIServerWithSSL(WsgiTestCase):
     """WSGI server with SSL tests."""
 
     def setUp(self):
-        super(TestWSGIServerWithSSL, self).setUp()
-        self.conf_fixture.register_opts(_options.ssl_opts,
-                                        sslutils.config_section)
+        super().setUp()
         cert_file_name = os.path.join(SSL_CERT_DIR, 'certificate.crt')
         key_file_name = os.path.join(SSL_CERT_DIR, 'privatekey.key')
         eventlet.monkey_patch(os=False, thread=False)
+        self.host = "127.0.0.1"
 
         self.config(cert_file=cert_file_name,
                     key_file=key_file_name,
                     group=sslutils.config_section)
 
-    @testtools.skipIf(six.PY3, "bug/1482633: test hangs on Python 3")
     def test_ssl_server(self):
         def test_app(env, start_response):
             start_response('200 OK', {})
             return ['PONG']
 
         fake_ssl_server = wsgi.Server(self.conf, "fake_ssl", test_app,
-                                      host="127.0.0.1", port=0, use_ssl=True)
+                                      host=self.host, port=0, use_ssl=True)
         fake_ssl_server.start()
         self.assertNotEqual(0, fake_ssl_server.port)
 
-        response = requests.post(
-            'https://127.0.0.1:%s/' % fake_ssl_server.port,
-            verify=os.path.join(SSL_CERT_DIR, 'ca.crt'), data='PING')
-        self.assertEqual('PONG', response.text)
+        response = requesting(
+            method='GET',
+            host=self.host,
+            port=fake_ssl_server.port,
+            ca_certs=os.path.join(SSL_CERT_DIR, 'ca.crt'),
+        )
+        self.assertEqual('PONG', response[-4:])
 
         fake_ssl_server.stop()
         fake_ssl_server.wait()
 
-    @testtools.skipIf(six.PY3, "bug/1482633: test hangs on Python 3")
     def test_two_servers(self):
         def test_app(env, start_response):
             start_response('200 OK', {})
@@ -318,14 +333,20 @@ class TestWSGIServerWithSSL(WsgiTestCase):
         fake_server.start()
         self.assertNotEqual(0, fake_server.port)
 
-        response = requests.post(
-            'https://127.0.0.1:%s/' % fake_ssl_server.port,
-            verify=os.path.join(SSL_CERT_DIR, 'ca.crt'), data='PING')
-        self.assertEqual('PONG', response.text)
+        response = requesting(
+            method='GET',
+            host='127.0.0.1',
+            port=fake_ssl_server.port,
+            ca_certs=os.path.join(SSL_CERT_DIR, 'ca.crt'),
+        )
+        self.assertEqual('PONG', response[-4:])
 
-        response = requests.post(
-            'http://127.0.0.1:%s/' % fake_server.port, data='PING')
-        self.assertEqual('PONG', response.text)
+        response = requesting(
+            method='GET',
+            host='127.0.0.1',
+            port=fake_server.port,
+        )
+        self.assertEqual('PONG', response[-4:])
 
         fake_ssl_server.stop()
         fake_ssl_server.wait()
@@ -336,7 +357,6 @@ class TestWSGIServerWithSSL(WsgiTestCase):
     @testtools.skipIf(platform.mac_ver()[0] != '',
                       'SO_REUSEADDR behaves differently '
                       'on OSX, see bug 1436895')
-    @testtools.skipIf(six.PY3, "bug/1482633: test hangs on Python 3")
     def test_socket_options_for_ssl_server(self):
         # test normal socket options has set properly
         self.config(tcp_keepidle=500)
@@ -355,8 +375,6 @@ class TestWSGIServerWithSSL(WsgiTestCase):
         server.stop()
         server.wait()
 
-    @testtools.skipIf(not netutils.is_ipv6_enabled(), "no ipv6 support")
-    @testtools.skipIf(six.PY3, "bug/1482633: test hangs on Python 3")
     def test_app_using_ipv6_and_ssl(self):
         greetings = 'Hello, World!!!'
 
@@ -372,9 +390,14 @@ class TestWSGIServerWithSSL(WsgiTestCase):
 
         server.start()
 
-        response = requests.get('https://[::1]:%d/' % server.port,
-                                verify=os.path.join(SSL_CERT_DIR, 'ca.crt'))
-        self.assertEqual(greetings, response.text)
+        response = requesting(
+            method='GET',
+            host='::1',
+            port=server.port,
+            ca_certs=os.path.join(SSL_CERT_DIR, 'ca.crt'),
+            address_familly=socket.AF_INET6
+        )
+        self.assertEqual(greetings, response[-15:])
 
         server.stop()
         server.wait()
